'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (section) {
  var engine = section.engine,
      selection = section.selection,
      command = section.command,
      locale = section.locale;

  var plugins = ['file', 'image', 'label'];
  var sections = (0, _section2.default)(engine);
  sections = sections.filter(function (plugin) {
    if (-1 !== plugins.indexOf(plugin.name)) {
      if ('label' === plugin.name) {
        plugin.onClick = function () {
          section.subEngine.command.execute('label');
        };
      }
      plugin.getDisabled = function () {
        return !selection.area;
      };
      plugin.name = 'table:' + plugin.name;
      return true;
    }
  });
  var fontnumberArray = [{
    key: '小五',
    value: '小五',
    ptSize: 9
  }, {
    key: '五号',
    value: '五号',
    ptSize: 11
  }, {
    key: '小四',
    value: '小四',
    ptSize: 12
  }, {
    key: '四号',
    value: '四号',
    ptSize: 14
  }, {
    key: '三号',
    value: '三号',
    ptSize: 16
  }, {
    key: '小二',
    value: '小二',
    ptSize: 18
  }, {
    key: '二号',
    value: '二号',
    ptSize: 22
  }, {
    key: '小一',
    value: '小一',
    ptSize: 24
  }, {
    key: '小初',
    value: '小初',
    ptSize: 36
  }];
  var fontnumberMap = {};
  var reverseFontnumberMap = {};
  var fontnumberKeyMap = {};
  fontnumberArray.forEach(function (fontnumber) {
    fontnumberMap[fontnumber.value] = fontnumber.ptSize;
    reverseFontnumberMap[fontnumber.ptSize] = fontnumber.value;
    fontnumberKeyMap[fontnumber.value] = fontnumber.value;
  });
  return [{
    name: 'table:section',
    type: 'collapse',
    title: locale.insertSection,
    icon: '<span class="zacheditor-icon zacheditor-icon-section" />',
    getDisabled: function getDisabled() {
      return !section.subEngine;
    },
    data: [{
      items: sections
    }],
    onClick: function onClick(name) {
      if (section.subEngine) {
        section.subEngine.command.execute(name);
      }
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:save',
    title: locale.save,
    hotkey: macos ? '\u2318+S' : 'Ctrl+S',
    icon: '<span class="zacheditor-icon zacheditor-icon-save" />',
    onClick: function onClick() {
      engine.command.execute('save');
    }
  }, {
    name: 'table:undo',
    title: locale.undo,
    hotkey: macos ? '\u2318+Z' : 'Ctrl+Z',
    icon: '<span class="zacheditor-icon zacheditor-icon-undo" />',
    getDisabled: function getDisabled() {
      if (section.subEngine && section.subEngine.command.queryState('undo')) {
        return false;
      }
      if (section.fullscreen) {
        return section.history.index === 0;
      }
      return !engine.command.queryState('undo');
    },
    onClick: function onClick() {
      section.undo();
    }
  }, {
    name: 'table:redo',
    title: locale.redo,
    hotkey: macos ? '\u2318+Shift+Z' : 'Ctrl+Shift+Z',
    icon: '<span class="zacheditor-icon zacheditor-icon-redo" />',
    getDisabled: function getDisabled() {
      if (section.subEngine && section.subEngine.command.queryState('redo')) {
        return false;
      }
      if (section.fullscreen) {
        return section.history.isEnd();
      }
      return !engine.command.queryState('redo');
    },
    onClick: function onClick() {
      section.redo();
    }
  }, {
    name: 'table:removeformat',
    title: locale.removeformat,
    icon: '<span class="zacheditor-icon zacheditor-icon-clean" />',
    onClick: function onClick() {
      command.clearFormat();
      command.execute('removeformat');
    }
  }, {
    type: 'separator'
  }, {
    name: 'fontsize',
    type: 'dropdown',
    title: locale.fontsizeTitle,
    className: 'zacheditor-button-fontsize',
    data: fontnumberArray,
    getActive: function getActive() {
      return reverseFontnumberMap[engine.command.queryState('fontsize')] || '小四';
    },
    getDisabled: function getDisabled() {
      var tag = engine.command.queryState('heading') || 'p';
      var isCodeblock = engine.command.queryState('codeblock') === 'codeblock';
      return (/^h\d$/.test(tag) || isCodeblock
      );
    },
    getCurrentText: function getCurrentText(active) {
      return fontnumberKeyMap[active] || '小四';
    },
    onClick: function onClick(value) {
      engine.command.execute('fontsize', value);
    }
  },
  // {
  //   name: 'table:emoji',
  //   type: 'dropdown',
  //   title: locale.emoji,
  //   icon: '<span class="zacheditor-icon zacheditor-icon-emoji" />',
  //   data: emoji,
  //   onClick: value => {
  //     section.subEngine && section.subEngine.command.execute('emoji', value);
  //   },
  // },
  {
    name: 'table:bold',
    title: locale.bold,
    hotkey: macos ? '\u2318+B' : 'Ctrl+B',
    icon: '<span class="zacheditor-icon zacheditor-icon-bold" />',
    getDisabled: function getDisabled() {
      return !section.selection.area;
    },
    getActive: function getActive() {
      return section.command.queryState('bold');
    },
    onClick: function onClick() {
      section.command.execute('bold');
    }
  }, {
    name: 'table:italic',
    title: locale.italic,
    hotkey: macos ? '\u2318+I' : 'Ctrl+I',
    icon: '<span class="zacheditor-icon zacheditor-icon-italic" />',
    getDisabled: function getDisabled() {
      return !section.selection.area;
    },
    getActive: function getActive() {
      return section.command.queryState('italic');
    },
    onClick: function onClick() {
      section.command.execute('italic');
    }
  }, {
    name: 'table:strikethrough',
    title: locale.strikethrough,
    key: macos ? '\u2318+Shift+X' : 'Ctrl+Shift+X',
    icon: '<span class="zacheditor-icon zacheditor-icon-strikethrough" />',
    getDisabled: function getDisabled() {
      return !section.selection.area;
    },
    getActive: function getActive() {
      return section.command.queryState('strikethrough');
    },
    onClick: function onClick() {
      section.command.execute('strikethrough');
    }
  }, {
    name: 'table:underline',
    title: locale.underline,
    key: macos ? '\u2318+U' : 'Ctrl+U',
    icon: '<span class="zacheditor-icon zacheditor-icon-underline" />',
    getDisabled: function getDisabled() {
      return !section.selection.area;
    },
    getActive: function getActive() {
      return section.command.queryState('underline');
    },
    onClick: function onClick() {
      section.command.execute('underline');
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:fontcolor',
    type: 'color',
    title: locale.fontcolor,
    moreTitle: locale.fontcolor,
    defaultColor: '#000000',
    currentColor: '#F5222D',
    getActive: function getActive() {
      return section.command.queryState('fontcolor') || [];
    },
    onClick: function onClick(value) {
      section.command.execute('fontcolor', value, '#000000');
    }
  }, {
    name: 'table:highlight',
    type: 'color',
    title: locale.highlightColor,
    moreTitle: locale.highlightColor,
    defaultColor: '#FFFFFF',
    currentColor: '#FADB14',
    getActive: function getActive() {
      return section.command.queryState('backcolor') || '';
    },
    onClick: function onClick(value) {
      section.command.execute('backcolor', value, '#FFFFFF');
    }
  }, {
    name: 'table:backcolor',
    type: 'color',
    title: locale.backcolor,
    moreTitle: locale.backcolor,
    defaultColor: '#FFFFFF',
    currentColor: '#f5f5f5',
    onClick: function onClick(value) {
      command.background(value);
    }
  }, {
    name: 'insertRowUp',
    title: locale.insertRowUp,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-insert-row-up" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.insertRowUp();
    }
  }, {
    name: 'insertRowDown',
    title: locale.insertRowDown,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-insert-row-down" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.insertRowDown();
    }
  }, {
    name: 'removeRow',
    title: locale.removeRow,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-remove-row" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.removeRow();
    }
  }, {
    type: 'separator'
  }, {
    name: 'insertColLeft',
    title: locale.insertColLeft,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-insert-col-left" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.insertColLeft();
    }
  }, {
    name: 'insertColRight',
    title: locale.insertColRight,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-insert-col-right" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.insertColRight();
    }
  }, {
    name: 'removeCol',
    title: locale.removeCol,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-remove-col" />',
    getDisabled: function getDisabled() {
      return !selection.area;
    },
    onClick: function onClick() {
      section.removeEditor();
      command.removeCol();
    }
  }, {
    type: 'separator'
  }, {
    name: 'mergecell',
    title: locale.mergeCell,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-merge-cell" />',
    getDisabled: function getDisabled() {
      return !selection.area || selection.isSingleArea();
    },
    onClick: function onClick() {
      command.mergeCell();
    }
  }, {
    name: 'splitCell',
    title: locale.splitCell,
    icon: '<span class="zacheditor-icon zacheditor-icon-table-split-cell" />',
    getDisabled: function getDisabled() {
      return !selection.hasMergeCell();
    },
    onClick: function onClick() {
      section.removeEditor();
      command.splitCell();
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:alignment',
    type: 'dropdown',
    title: locale.align,
    icon: '<span class="zacheditor-icon zacheditor-icon-align-left" />',
    className: 'zacheditor-button-icon-list',
    data: [{
      key: 'left',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-left" />',
      title: locale.alignLeft,
      className: 'zacheditor-button-set-list-item-icon'
    }, {
      key: 'center',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-center" />',
      title: locale.alignCenter,
      className: 'zacheditor-button-set-list-item-icon'
    }, {
      key: 'right',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-right" />',
      title: locale.alignRight,
      className: 'zacheditor-button-set-list-item-icon'
    }, {
      key: 'justify',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-justify" />',
      title: locale.alignJustify,
      className: 'zacheditor-button-set-list-item-icon'
    }],
    getActive: function getActive() {
      return command.queryState('alignment');
    },
    onClick: function onClick(value) {
      command.align(value);
    }
  }, {
    name: 'table:verticalAlignment',
    type: 'dropdown',
    title: locale.verticalAlign,
    icon: '<span class="zacheditor-icon zacheditor-icon-align-top" />',
    className: 'zacheditor-button-icon-list',
    data: [{
      key: 'top',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-top" />',
      title: locale.alignTop,
      className: 'zacheditor-button-set-list-item-icon'
    }, {
      key: 'middle',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-middle" />',
      title: locale.alignMiddle,
      className: 'zacheditor-button-set-list-item-icon'
    }, {
      key: 'bottom',
      icon: '<span class="zacheditor-icon zacheditor-icon-align-bottom" />',
      title: locale.alignBottom,
      className: 'zacheditor-button-set-list-item-icon'
    }],
    getActive: function getActive() {
      return command.queryState('alignment');
    },
    onClick: function onClick(value) {
      command.valign(value);
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:unorderedlist',
    title: locale.unorderedList,
    hotkey: macos ? '\u2318+Shift+8' : 'Ctrl+Shift+8',
    icon: '<span class="zacheditor-icon zacheditor-icon-unordered-list" />',
    getDisabled: function getDisabled() {
      return !section.subEngine;
    },
    getActive: function getActive() {
      return section.subEngine && section.subEngine.command.queryState('tasklist') === 'unorderedlist';
    },
    onClick: function onClick() {
      section.subEngine && section.subEngine.command.execute('tasklist', 'unorderedlist');
    }
  }, {
    name: 'table:orderedlist',
    title: locale.orderedList,
    hotkey: macos ? '\u2318+Shift+7' : 'Ctrl+Shift+7',
    icon: '<span class="zacheditor-icon zacheditor-icon-ordered-list" />',
    getDisabled: function getDisabled() {
      return !section.subEngine;
    },
    getActive: function getActive() {
      return section.subEngine && section.subEngine.command.queryState('tasklist') === 'orderedlist';
    },
    onClick: function onClick() {
      section.subEngine && section.subEngine.command.execute('tasklist', 'orderedlist');
    }
  }, {
    name: 'table:tasklist',
    title: locale.taskList,
    icon: '<span class="zacheditor-icon zacheditor-icon-task-list" />',
    getDisabled: function getDisabled() {
      return !section.subEngine;
    },
    getActive: function getActive() {
      return section.subEngine && section.subEngine.command.queryState('tasklist') === 'tasklist';
    },
    onClick: function onClick() {
      section.subEngine && section.subEngine.command.execute('tasklist', 'tasklist');
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:link',
    title: locale.link,
    className: 'zacheditor-button-link',
    hotkey: macos ? '\u2318+K' : 'Ctrl+K',
    icon: '<span class="zacheditor-icon zacheditor-icon-link" />',
    getDisabled: function getDisabled() {
      return !section.subEngine;
    },
    onClick: function onClick() {
      section.subEngine && section.subEngine.command.execute('link');
    }
  }, {
    type: 'separator'
  }, {
    name: 'table:blankmark',
    icon: '<span class="zacheditor-svg-icon zacheditor-svg-icon-blankmark" />',
    title: locale.blankmark.title,
    pinyin: 'tiankongbiaoji,blankmark',
    description: locale.blankmark.description,
    onClick: function onClick() {
      engine.command.execute('blankmark');
    }
  }];
};

var _section = require('../../config/section');

var _section2 = _interopRequireDefault(_section);

var _tinsoEditorEngine = require('tinso-editor-engine');

var _tinsoEditorEngine2 = _interopRequireDefault(_tinsoEditorEngine);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var macos = _tinsoEditorEngine2.default.userAgent.macos;